@@ -344,7 +344,8 @@ class JsonObj(JsonObjMutableMapping):
         try:
             return self.dot_lookup(key)
         except KeyError:
-            raise KeyError(str(key))
+            ...
+        raise KeyError(str(key))
 
     def __delitem__(self, key: str) -> None:
         return self._data.__delitem__(key)
@@ -618,8 +619,7 @@ class JsonObj(JsonObjMutableMapping):
                 'strings will be split on \'.\''
             )
         parts = key.split(".") if isinstance(key, str) else list(key)
-
-        root_val: Any = self._data.get(parts[0])
+        root_val: Any = self._data[parts[0]]
         cur_val = root_val
         for ix, part in enumerate(parts[1:], start=1):
             try:
@@ -778,11 +778,12 @@ class JsonObj(JsonObjMutableMapping):
             <class 'dict'>
 
         """
-        return {
-            k: unjsonify(v)
-            # if not isinstance(v, JsonObj) else v.eject()
-            for k, v in self._data.items()
-        }
+        try:
+            return {k: unjsonify(v) for k, v in self._data.items()}
+        except RecursionError:
+            raise ValueError(
+                'JSON.stringify recursion err; cycle/circular-refs detected'
+            )
 
     def to_dict(self) -> Dict[str, Any]:
         """Return the JsonObj object (and children) as a python dictionary"""
@@ -911,7 +912,7 @@ def jsonify(value: Any) -> Any:
 def unjsonify(value: Any) -> Any:
     """Recursively eject a JsonDit object"""
     if isinstance(value, JsonObj):
-        return {k: unjsonify(v) for k, v in value._data.items()}
+        return value._data
     if isinstance(value, list):
         return [unjsonify(el) for el in value]
     if isinstance(value, tuple):
@@ -1013,9 +1014,26 @@ class JSON(metaclass=JSONMeta):
         return json.loads(string)
 
     @staticmethod
-    def json_lib() -> Any:
+    def use_orjson() -> None:
+        json.use_orjson()
+
+    @staticmethod
+    def use_rapidjson() -> None:
+        json.use_rapidjson()
+
+    @staticmethod
+    def use_json_stdlib() -> None:
+        json.use_json_stdlib()
+
+    @staticmethod
+    def which() -> str:
         """Return the name of the JSON library being used as a backend"""
-        return json._json.__class__.__name__
+        return json.which()
+
+    @staticmethod
+    def json_lib() -> str:
+        """Return the name of the JSON library being used as a backend"""
+        return json.which()
 
     @staticmethod
     def jsonify(value: Any) -> Any:
